@@ -537,6 +537,9 @@ class Query:
                                 formatted_cond = where_condition.field.complexExpression
 
                         conditions.append(formatted_cond)
+                elif where_condition.field.complexExpression is not None:
+                    formatted_cond = where_condition.field.complexExpression
+                    conditions.append(formatted_cond)
             elif isinstance(where_condition, CompositeCondition):
                 other_conds = self._where_spell_out(where_condition.conditions)
                 if where_condition.operator.name == "AND":
