@@ -39,8 +39,8 @@ if __name__ == "__main__":
     print("#--------------------------SmartNER Offline Test--------------------------#")
 
     # Usage
-    nl = "units"
-    df = pd.read_excel("./dataset.xlsx")
+    nl = "units ordered"
+    df = pd.read_excel("./inventory.xlsx")
 
     start = time.time()
     smartquery_list = nlp(nl=nl, dataframe=df)
