@@ -45,7 +45,10 @@ if __name__ == '__main__':
                          operator="FROM", value=["2022"]),
                Condition(Field(column="units shipped", aggregation="MAX", alias="max_units_shipped", internalDataType="NUMERIC",
                                sourceDataType="REAL"),
-                         operator="GOE", value=["100"])
+                         operator="GOE", value=["100"]),
+               Condition(Field(complexExpression="sum units shipped & 10 > 10", alias="sum_units_shipped",
+                               internalDataType="NUMERIC",
+                               sourceDataType="REAL"))
                ],
         orderBy=[Sorting(field="Store City", order=SQLSorting.DESC),
                  Sorting(field="Time", order=SQLSorting.DESC)],
